@@ -10,7 +10,7 @@ import matplotlib.pyplot as pyplot
 
 
 
-def generate_demographic_contact_network(N, demographic_data, layer_generator='LFR', layer_info=None, distancing_scales=[], isolation_groups=[]):
+def generate_demographic_contact_network(N, demographic_data, layer_generator='FARZ', layer_info=None, distancing_scales=[], isolation_groups=[]):
 
     graphs = {}
 
@@ -327,7 +327,7 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='L
 
                     # print "TARGET MEAN DEGREE     = " + str(targetMeanDegree)
                 
-                    layerInfo['graph'] = networkx.algorithms.community.LFR_benchmark_graph(
+                    layerInfo['graph'] = networkx.generators.community.LFR_benchmark_graph(
                                             n=layerInfo['numIndividuals'], 
                                             tau1=3, tau2=2, mu=0.5, 
                                             average_degree=int(targetMeanDegree), 
@@ -335,10 +335,6 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='L
 
                 elif(layer_generator == 'FARZ'):
 
-                    # print 
-                    # print "TARGET MEAN DEGREE     = " + str(targetMeanDegree)
-                    # print "TARGET MEAN DEGREE / 2 = " + str(int(targetMeanDegree/2))
-
                     # https://github.com/rabbanyk/FARZ
                     layerInfo['graph'], layerInfo['communities'] = FARZ.generate(farz_params={ 
                                                                     'n': layerInfo['numIndividuals'], 
@@ -614,22 +610,17 @@ def household_country_data(country):
 
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-# Define a custom method for generating 
-# power-law-like graphs with exponential tails 
-# both above and below the degree mean and  
+# Defines a random exponential edge pruning mechanism   
 # where the mean degree be easily down-shifted
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 def custom_exponential_graph(base_graph=None, scale=100, min_num_edges=0, m=9, n=None):
-    # Generate a random preferential attachment power law graph as a starting point.
-    # By the way this graph is constructed, it is expected to have 1 connected component.
-    # Every node is added along with m=8 edges, so the min degree is m=8.
+    # If no base graph is provided, generate a random preferential attachment power law graph as a starting point.
     if(base_graph):
         graph = base_graph.copy()
     else:
         assert(n is not None), "Argument n (number of nodes) must be provided when no base graph is given."
         graph = networkx.barabasi_albert_graph(n=n, m=m)
 
-    # To get a graph with power-law-esque properties but without the fixed minimum degree,
     # We modify the graph by probabilistically dropping some edges from each node. 
     for node in graph:
         neighbors = list(graph[node].keys())
